Struct OrderedWorker

pub struct OrderedWorker<T, R>
where T: Send + 'static, R: Send + 'static,
{ /* private fields */ }
A worker that processes tasks in parallel using multiple worker threads. The results are returned in same order as the tasks were added.