pub struct OrderedWorker<T, R>{ /* private fields */ }Expand description
A worker that processes tasks in parallel using multiple worker threads. The results are returned in same order as the tasks were added.